#..........................................................................................
### ~~ R CODE TO CREATE ToT VARIABLES FOR SOMALIA DEATH TOLL ANALYSIS (2010-2012) ~~ ###

# Written by Francesco Checchi, LSHTM (November 2012)
# francesco.checchi@lshtm.ac.uk 


#..........................................................................................
### Preparatory

rm(list=ls(all=TRUE))

# working directory
setwd("C:/Users/Francesco/Desktop/Analysis")
#setwd("H:/Francesco/LSHTM academic 2009-/FSNAU Somalia/Analysis")


#.........................................................................................
### Read and clean data

# read dataset of eligible markets
markets <- read.csv("markets.csv")

# read dataset of cereal milling losses and Kcal equivalents
cereals <- read.csv("cereals.csv")
# create conversion factor for each cereal
cereals[, "conv"] <- cereals[, "milling_rec"] * cereals[, "kcal_1kg"]

# read market price dataset
prices <- read.csv("market_data_analysis.csv")

# restrict period to June 2006 and beyond
prices[, "ym"] <- prices[, "y"]*100 + prices[, "m"]
prices <- subset(prices, ym>200605)

# restrict markets to those that are eligible
prices <- merge(prices, markets[, c("market", "eligible")], by="market" )

#sort data
prices <- prices[order(prices[, "market"], prices[, "y"], prices[, "m"]) , ]


#.........................................................................................
### Smooth data

# create columns to hold smoothed values
prices[, c("s_sor_w_1", "s_sor_r_1", "s_mze_y_1", "s_mze_w_1", "s_rce_r_1", "s_wht_f_1", "s_goat_l", "s_wage")] <- NA

# for each market...
for (i in c(unique(as.character(prices[, "market"])) ) ) {

	# capture data from market i 
	prices.i <- subset(prices, market==i)
	prices.i[, "tm"] <- seq(1, nrow(prices.i), 1)
	
	# for each variable to be smoothed...
	for (j in c("sor_w_1", "sor_r_1", "mze_y_1", "mze_w_1", "rce_r_1", "wht_f_1", "goat_l", "wage") ) {
	
		# interpolate time series which contain some data but do not start and end on June 2006/May 2012
		if ( (length(na.omit(prices.i[, j]) ) > 0 )  & (is.na(prices.i[1, j]) == TRUE ) ) 
			{
				prices.i[1, j] <- na.omit(prices.i[, j])[1]
			}

		if ( (length(na.omit(prices.i[, j]) ) > 0 )  & (is.na(prices.i[nrow(prices.i), j]) == TRUE ) ) 
			{
				prices.i[nrow(prices.i), j] <- na.omit(prices.i[, j])[length(na.omit(prices.i[, j]) )]
			}

		# capture variables and omit missing values
		prices.ij <- na.omit( prices.i[, c(j, "tm")] )

		if ( (nrow(prices.ij) / nrow(prices.i) ) < 0.75) {
			
			# if variable has insufficient data coverage of time series, return a series of NA values and update dataset of smoothed data accordingly
			prices[ match(i, prices[, "market"]) : (match(i, prices[, "market"]) + nrow(prices.i) - 1) , paste("s_", j, sep="") ] <- rep(NA, nrow(prices.i) )	
			
			}
		
		else
			
			{
			
			# smooth variable and extrapolate (predict) missing ones
			sm <- predict( smooth.spline(prices.ij[, "tm"], prices.ij[, j], spar = 0.5) , prices.i[, "tm"] )

			# inspect result of smoothing
			plot(prices.i[, "tm"], prices.i[, j])
			lines(prices.i[, j])
			lines(sm, col="blue")
			##Sys.sleep(1)
			
			# update dataset with smoothed data
			prices[ match(i, prices[, "market"]) : (match(i, prices[, "market"]) + nrow(prices.i) - 1) , paste("s_", j, sep="") ] <- sm["y"]
			
			}
			
		}

	}


#.........................................................................................
### Calculate various ToT indices

# define reference values for ToT [not done in final analysis]
#ref_sor_w_1 <- subset(prices, market=="Baidoa" & y=="2006" & m=="6")["s_sor_w_1"]
#ref_sor_r_1 <- subset(prices, market=="Baidoa" & y=="2006" & m=="6")["s_sor_r_1"]
#ref_mze_y_1 <- subset(prices, market=="Baidoa" & y=="2006" & m=="6")["s_mze_y_1"]
#ref_mze_w_1 <- subset(prices, market=="Baidoa" & y=="2006" & m=="6")["s_mze_w_1"]
#ref_rce_r_1 <- subset(prices, market=="Baidoa" & y=="2006" & m=="6")["s_rce_r_1"]
#ref_wht_f_1 <- subset(prices, market=="Baidoa" & y=="2006" & m=="6")["s_wht_f_1"]
#ref_goat_l  <- subset(prices, market=="Baidoa" & y=="2006" & m=="6")["s_goat_l"]
#ref_wage    <- subset(prices, market=="Baidoa" & y=="2006" & m=="6")["s_wage"]

#Calculate absolute ToT trading wages for cereals, for each cereal, and re-expressed as Kcal equivalent after adjusting for home milling loss
prices[, "AToTw_sor_w"] <- as.numeric(cereals[which(cereals[, "cereal"] == "sor_w_1"), "conv"]) * ( prices[, "s_wage"] / prices[, "s_sor_w_1"] )
prices[, "AToTw_sor_r"] <- as.numeric(cereals[which(cereals[, "cereal"] == "sor_r_1"), "conv"]) * ( prices[, "s_wage"] / prices[, "s_sor_r_1"] )
prices[, "AToTw_mze_y"] <- as.numeric(cereals[which(cereals[, "cereal"] == "mze_y_1"), "conv"]) * ( prices[, "s_wage"] / prices[, "s_mze_y_1"] )
prices[, "AToTw_mze_w"] <- as.numeric(cereals[which(cereals[, "cereal"] == "mze_w_1"), "conv"]) * ( prices[, "s_wage"] / prices[, "s_mze_w_1"] )
prices[, "AToTw_rce_r"] <- as.numeric(cereals[which(cereals[, "cereal"] == "rce_r_1"), "conv"]) * ( prices[, "s_wage"] / prices[, "s_rce_r_1"] )
prices[, "AToTw_wht_f"] <- as.numeric(cereals[which(cereals[, "cereal"] == "wht_f_1"), "conv"]) * ( prices[, "s_wage"] / prices[, "s_wht_f_1"] )

	# calculate composite absolute ToT (wages vs cereals) as the weighted mean of all the non-missing cereal-specific values (weights being the ToT themselves)
	f.atotw <- function(f.prices) {

		return (weighted.mean( c( as.numeric(f.prices[["AToTw_sor_w"]]) , as.numeric(f.prices[["AToTw_sor_r"]]) , as.numeric(f.prices[["AToTw_mze_y"]]) ,
						          as.numeric(f.prices[["AToTw_mze_w"]]) , as.numeric(f.prices[["AToTw_rce_r"]]) , as.numeric(f.prices[["AToTw_wht_f"]])
					            ) ,
							   c( as.numeric(f.prices[["AToTw_sor_w"]]) , as.numeric(f.prices[["AToTw_sor_r"]]) , as.numeric(f.prices[["AToTw_mze_y"]]) ,
						          as.numeric(f.prices[["AToTw_mze_w"]]) , as.numeric(f.prices[["AToTw_rce_r"]]) , as.numeric(f.prices[["AToTw_wht_f"]])
					            ) ,
								na.rm=TRUE
					  )
			   ) 
		}

	prices[, "AToTw_comp"] <- apply(prices, 1, f.atotw)



#Calculate absolute ToT trading goats for cereals, for each cereal, and re-expressed as Kcal equivalent after adjusting for home milling loss
prices[, "AToTg_sor_w"] <- cereals[which(cereals[, "cereal"] == "sor_w_1"), "conv"] * ( prices[, "s_goat_l"] / prices[, "s_sor_w_1"] )
prices[, "AToTg_sor_r"] <- cereals[which(cereals[, "cereal"] == "sor_r_1"), "conv"] * ( prices[, "s_goat_l"] / prices[, "s_sor_r_1"] )
prices[, "AToTg_mze_y"] <- cereals[which(cereals[, "cereal"] == "mze_y_1"), "conv"] * ( prices[, "s_goat_l"] / prices[, "s_mze_y_1"] )
prices[, "AToTg_mze_w"] <- cereals[which(cereals[, "cereal"] == "mze_w_1"), "conv"] * ( prices[, "s_goat_l"] / prices[, "s_mze_w_1"] )
prices[, "AToTg_rce_r"] <- cereals[which(cereals[, "cereal"] == "rce_r_1"), "conv"] * ( prices[, "s_goat_l"] / prices[, "s_rce_r_1"] )
prices[, "AToTg_wht_f"] <- cereals[which(cereals[, "cereal"] == "wht_f_1"), "conv"] * ( prices[, "s_goat_l"] / prices[, "s_wht_f_1"] )

	# calculate composite absolute ToT (goats vs cereals) as the weighted mean of all the non-missing cereal-specific values (weights being the ToT themselves)
	f.atotg <- function(f.prices) {

		return (weighted.mean( c( as.numeric(f.prices[["AToTg_sor_w"]]) , as.numeric(f.prices[["AToTg_sor_r"]]) , as.numeric(f.prices[["AToTg_mze_y"]]) ,
						          as.numeric(f.prices[["AToTg_mze_w"]]) , as.numeric(f.prices[["AToTg_rce_r"]]) , as.numeric(f.prices[["AToTg_wht_f"]])
					            ) ,
							   c( as.numeric(f.prices[["AToTg_sor_w"]]) , as.numeric(f.prices[["AToTg_sor_r"]]) , as.numeric(f.prices[["AToTg_mze_y"]]) ,
						          as.numeric(f.prices[["AToTg_mze_w"]]) , as.numeric(f.prices[["AToTg_rce_r"]]) , as.numeric(f.prices[["AToTg_wht_f"]])
					            ) ,
								na.rm=TRUE
					  )
			   ) 
		}

	prices[, "AToTg_comp"] <- apply(prices, 1, f.atotg)


	
#Calculate relative ToT trading wages for cereals, for each cereal (no need for Kcal equivalent as these are relative values)

# for each market...
for (i in c(unique(as.character(prices[, "market"])) ) ) {

	# capture data from market i 
	prices.i <- subset(prices, market==i)
		
	# for each cereal...
	for (j in c("sor_w_1", "sor_r_1", "mze_y_1", "mze_w_1", "rce_r_1", "wht_f_1") ) {

			# update database accordingly
			prices[ match(i, prices[, "market"]) : (match(i, prices[, "market"]) + nrow(prices.i) - 1) , paste("RToTw_", substr(j, 1, 5), sep="") ] <- 
			
				( prices.i[, "s_wage"] / prices.i[, paste("s_", j, sep="")] ) / 
				as.numeric( prices.i[1, "s_wage"] / prices.i[1, paste("s_", j, sep="")] )

		}

	}

	
	# calculate composite relative ToT (wages vs cereals) as the mean of all the non-missing cereal-specific values
	f.rtotw <- function(f.prices) {

		return (mean( c( as.numeric(f.prices[["RToTw_sor_w"]]) , as.numeric(f.prices[["RToTw_sor_r"]]) , as.numeric(f.prices[["RToTw_mze_y"]]) ,
						          as.numeric(f.prices[["RToTw_mze_w"]]) , as.numeric(f.prices[["RToTw_rce_r"]]) , as.numeric(f.prices[["RToTw_wht_f"]])
					            ) ,
								na.rm=TRUE
					  )
			   ) 
		}

	prices[, "RToTw_comp"] <- apply(prices, 1, f.rtotw)

	
#Calculate relative ToT trading goats for cereals, for each cereal (no need for Kcal equivalent as these are relative values)

# for each market...
for (i in c(unique(as.character(prices[, "market"])) ) ) {

	# capture data from market i 
	prices.i <- subset(prices, market==i)
		
	# for each cereal...
	for (j in c("sor_w_1", "sor_r_1", "mze_y_1", "mze_w_1", "rce_r_1", "wht_f_1") ) {

			# update database accordingly
			prices[ match(i, prices[, "market"]) : (match(i, prices[, "market"]) + nrow(prices.i) - 1) , paste("RToTg_", substr(j, 1, 5), sep="") ] <- 
			
				( prices.i[, "s_goat_l"] / prices.i[, paste("s_", j, sep="")] ) / 
				as.numeric( prices.i[1, "s_goat_l"] / prices.i[1, paste("s_", j, sep="")] )

		}

	}

	
	# calculate composite relative ToT (goats vs cereals) as the mean of all the non-missing cereal-specific values
	f.rtotg <- function(f.prices) {

		return (mean( c( as.numeric(f.prices[["RToTg_sor_w"]]) , as.numeric(f.prices[["RToTg_sor_r"]]) , as.numeric(f.prices[["RToTg_mze_y"]]) ,
						          as.numeric(f.prices[["RToTg_mze_w"]]) , as.numeric(f.prices[["RToTg_rce_r"]]) , as.numeric(f.prices[["RToTg_wht_f"]])
					            ) ,
								na.rm=TRUE
					  )
			   ) 
		}

	prices[, "RToTg_comp"] <- apply(prices, 1, f.rtotg)


# Add market weights (proxy = urban population in district where market is located)
markets <- read.csv("markets.csv")
prices <- merge(prices, markets[, c("market", "market_wt")], by="market")
	

#.........................................................................................
### Observe differences between cereals and different ToT indices

## Differences in AToTw among cereals
	
# for each market...
for (i in c(unique(as.character(prices[, "market"])) ) ) {

	# capture data from market i 
	prices.i <- subset(prices, market==i)
	
	# call a new plot
	plot(seq(1, nrow(prices.i), 1), prices.i[, "AToTw_wht_f"], col = "white", main = i , xlab = "month", ylab = "AToT (wage vs cereal)" ,
	     ylim = c(0, max(prices.i[, c("AToTw_sor_w", "AToTw_sor_r", "AToTw_mze_y", "AToTw_mze_w", "AToTw_rce_r", "AToTw_wht_f")], na.rm=TRUE)) )
	
	# for each cereal...
	for (j in c("sor_w", "sor_r", "mze_y", "mze_w", "rce_r", "wht_f") ) {
			
			# decide plot colour
			colour <- c("blue", "red", "green", "violet", "orange", "brown")[match(j, c("sor_w", "sor_r", "mze_y", "mze_w", "rce_r", "wht_f") )]
			
			# plot line graph for cereal
			lines(prices.i[, paste("AToTw_", j, sep="") ], col= colour) 

		}
	
	# add legend
	lnames <- c("white sorghum", "red sorghum", "yellow maize", "white maize", "red rice", "wheat flour")
	legend("top", legend = lnames, lty = "solid", col = c("blue", "red", "green", "violet", "orange", "brown"), bty="n", ncol=3) 
	
	#Sys.sleep(1)
		
	}

## Differences in AToTg among cereals
	
# for each market...
for (i in c(unique(as.character(prices[, "market"])) ) ) {

	# capture data from market i 
	prices.i <- subset(prices, market==i)
	
	# call a new plot
	plot(seq(1, nrow(prices.i), 1), prices.i[, "AToTg_wht_f"], col = "white", main = i , xlab = "month", ylab = "AToT (goat vs cereal)" ,
	     ylim = c(0, max(prices.i[, c("AToTg_sor_w", "AToTg_sor_r", "AToTg_mze_y", "AToTg_mze_w", "AToTg_rce_r", "AToTg_wht_f")], na.rm=TRUE)) )
	
	# for each cereal...
	for (j in c("sor_w", "sor_r", "mze_y", "mze_w", "rce_r", "wht_f") ) {
			
			# decide plot colour
			colour <- c("blue", "red", "green", "violet", "orange", "brown")[match(j, c("sor_w", "sor_r", "mze_y", "mze_w", "rce_r", "wht_f") )]
			
			# plot line graph for cereal
			lines(prices.i[, paste("AToTg_", j, sep="") ], col= colour) 

		}
	
	# add legend
	lnames <- c("white sorghum", "red sorghum", "yellow maize", "white maize", "red rice", "wheat flour")
	legend("top", legend = lnames, lty = "solid", col = c("blue", "red", "green", "violet", "orange", "brown"), bty="n", ncol=3) 
	
	#Sys.sleep(1)
		
	}

## Differences between the composite AToTw and AToTg

# for each market...
for (i in c(unique(as.character(prices[, "market"])) ) ) {

	# capture data from market i 
	prices.i <- subset(prices, market==i)
	
	# plot AToTw
	par(mar=c(5,4,4,5)+.1)
	plot(seq(1, nrow(prices.i), 1), prices.i[, "AToTw_comp"], type="l", col = "red", main = i , xlab = "month", ylab="AToTw (composite)")
			
	# plot AToTg
	par(new = TRUE)
	plot(seq(1, nrow(prices.i), 1), prices.i[, "AToTg_comp"], type="l", col = "blue", xaxt="n", yaxt="n", xlab="", ylab="")
	axis(4)
	mtext("AToTg (composite)", side=4)
	
	# add legend
	lnames <- c("wage vs cereal", "goat vs cereal")
	legend("top", legend = lnames, lty = "solid", col = c("red", "blue"), bty="n", ncol=2) 
	
	#Sys.sleep(1)
		
	}
	
	
	
## Differences in RToTw among cereals
	
# for each market...
for (i in c(unique(as.character(prices[, "market"])) ) ) {

	# capture data from market i 
	prices.i <- subset(prices, market==i)
	
	# call a new plot
	plot(seq(1, nrow(prices.i), 1), prices.i[, "RToTw_wht_f"], col = "white", main = i , xlab = "month", ylab = "RToT (wage vs cereal)" ,
	     ylim = c(0, max(prices.i[, c("RToTw_sor_w", "RToTw_sor_r", "RToTw_mze_y", "RToTw_mze_w", "RToTw_rce_r", "RToTw_wht_f")], na.rm=TRUE)) )
	
	# for each cereal...
	for (j in c("sor_w", "sor_r", "mze_y", "mze_w", "rce_r", "wht_f") ) {
			
			# decide plot colour
			colour <- c("blue", "red", "green", "violet", "orange", "brown")[match(j, c("sor_w", "sor_r", "mze_y", "mze_w", "rce_r", "wht_f") )]
			
			# plot line graph for cereal
			lines(prices.i[, paste("RToTw_", j, sep="") ], col= colour) 

		}
	
	# add legend
	lnames <- c("white sorghum", "red sorghum", "yellow maize", "white maize", "red rice", "wheat flour")
	legend("top", legend = lnames, lty = "solid", col = c("blue", "red", "green", "violet", "orange", "brown"), bty="n", ncol=3) 
	
	#Sys.sleep(1)
		
	}

## Differences in RToTg among cereals
	
# for each market...
for (i in c(unique(as.character(prices[, "market"])) ) ) {

	# capture data from market i 
	prices.i <- subset(prices, market==i)
	
	# call a new plot
	plot(seq(1, nrow(prices.i), 1), prices.i[, "RToTg_wht_f"], col = "white", main = i , xlab = "month", ylab = "RToT (goat vs cereal)" ,
	     ylim = c(0, max(prices.i[, c("RToTg_sor_w", "RToTg_sor_r", "RToTg_mze_y", "RToTg_mze_w", "RToTg_rce_r", "RToTg_wht_f")], na.rm=TRUE)) )
	
	# for each cereal...
	for (j in c("sor_w", "sor_r", "mze_y", "mze_w", "rce_r", "wht_f") ) {
			
			# decide plot colour
			colour <- c("blue", "red", "green", "violet", "orange", "brown")[match(j, c("sor_w", "sor_r", "mze_y", "mze_w", "rce_r", "wht_f") )]
			
			# plot line graph for cereal
			lines(prices.i[, paste("RToTg_", j, sep="") ], col= colour) 

		}
	
	# add legend
	lnames <- c("white sorghum", "red sorghum", "yellow maize", "white maize", "red rice", "wheat flour")
	legend("top", legend = lnames, lty = "solid", col = c("blue", "red", "green", "violet", "orange", "brown"), bty="n", ncol=3) 
	
	#Sys.sleep(1)
		
	}

## Differences between the composite RToTw and RToTg

# for each market...
for (i in c(unique(as.character(prices[, "market"])) ) ) {

	# capture data from market i 
	prices.i <- subset(prices, market==i)
	
	# plot RToTw
	par(mar=c(5,4,4,5)+.1)
	plot(seq(1, nrow(prices.i), 1), prices.i[, "RToTw_comp"], type="l", col = "red", main = i , xlab = "month", ylab="RToTw (composite)")
			
	# plot RToTg
	par(new = TRUE)
	plot(seq(1, nrow(prices.i), 1), prices.i[, "RToTg_comp"], type="l", col = "blue", xaxt="n", yaxt="n", xlab="", ylab="")
	axis(4)
	mtext("RToTg (composite)", side=4)
	
	# add legend
	lnames <- c("wage vs cereal", "goat vs cereal")
	legend("top", legend = lnames, lty = "solid", col = c("red", "blue"), bty="n", ncol=2) 
	
	#Sys.sleep(1)
		
	}
	

#.........................................................................................
### Write to file
write.csv(prices, "market_data_analysis.csv" , row.names=FALSE)

